@@ -1,7 +1,7 @@
 #!/usr/bin/env python
-# $Id: simple.py,v 1.2 2004/03/21 02:25:54 belyi Exp $
-# Copyright (C) 2002 John Goerzen
-# <jgoerzen@complete.org>
+# $Id: simple.py,v 1.5 2008/03/08 18:21:08 belyi Exp $
+# Copyright (C) 2005 Igor Belyi <belyi@users.sourceforge.net>
+# Copyright (C) 2002 John Goerzen <jgoerzen@complete.org>
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -18,9 +18,11 @@
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 import sys
-from pyme import core, constants
+from pyme import core, constants, errors
 import pyme.constants.validity
 
+core.check_version(None)
+
 # Set up our input and output buffers.
 
 plain = core.Data('This is my message.')
@@ -38,8 +40,13 @@ name = sys.stdin.readline().strip()
 c.op_keylist_start(name, 0)
 r = c.op_keylist_next()
 
-# Do the encryption.
-
-c.op_encrypt([r], 1, plain, cipher)
-cipher.seek(0,0)
-print cipher.read()
+if r == None:
+    print "The key for user \"%s\" was not found" % name
+else:
+    # Do the encryption.
+    try:
+        c.op_encrypt([r], 1, plain, cipher)
+        cipher.seek(0,0)
+        print cipher.read()
+    except errors.GPGMEError, ex:
+        print ex.getstring()
