@@ -1,13 +1,14 @@
 #!/usr/bin/env python
 # initial 20080124 bernhard@intevation.de
 # 20080124-2: removed some superflous imports
+# 20080703: adapted for pyme-0.8.0
 # This script is Free Software under GNU GPL v>=2.
 """A test applicaton for gpg_get_key() protocol.CMS.
 
-Tested on Debian Sid with  
-    python-pyme    0.7.0-3
-    libgpgme11     1.1.6-1 
-    gpgsm          2.0.8-1
+Tested on Debian Etch with
+    pyme           0.8.0 (manually compiled)
+    libgpgme11     1.1.6-0kk2
+    gpgsm          2.0.9-0kk2
 """
 
 import sys
@@ -25,11 +26,10 @@ def printgetkeyresults(keyfpr):
 
     key = c.get_key(keyfpr, False)
 
-    print "got key: ", key.subkeys.fpr
-    uid = key.uids
-    while (uid):
+    print "got key: ", key.subkeys[0].fpr
+
+    for uid in key.uids:
         print uid.uid
-        uid = uid.next
 
 def main():
     if len(sys.argv) < 2:
@@ -41,3 +41,5 @@ def main():
 
 if __name__ == "__main__":
     main()
+
+ 	  	 
