@@ -1,5 +1,5 @@
 /*
-# $Id: helpers.h,v 1.7 2005/04/21 03:53:11 belyi Exp $
+# $Id: helpers.h,v 1.8 2008/11/26 02:38:33 belyi Exp $
 # Copyright (C) 2004 Igor Belyi <belyi@users.sourceforge.net>
 # Copyright (C) 2002 John Goerzen <jgoerzen@complete.org>
 #
@@ -21,6 +21,11 @@
 #include <gpgme.h>
 #include "Python.h"
 
+#ifdef _WIN32
+#include <windows.h>
+#define write(fd, str, sz) {DWORD written; WriteFile((HANDLE) fd, str, sz, &written, 0);}
+#endif
+
 void pygpgme_exception_init(void);
 gpgme_error_t pygpgme_exception2code(void);
 
